mattd - Matt Daemon
===================

mattd is a voice-to-text driven plugin system.  Its like an IRCBot for
"real-life".  The gist:

 - Write plugins to carry out actions when you speak certain phrases.
 - Take advantage of `community plugins
   <http://pypi.python.org/pypi?%3Aaction=search&term=mattd&submit=search>`_.

Caveat
------

Its not pure python.  Your best bet is to install it from `your friendly Linux
distribution's package management system
<https://apps.fedoraproject.org/packages/mattd>`_.
